@@ -5,7 +5,7 @@
 // </script>
 // Constructor for animint Object.
 var animint = function (to_select, json_file) {
-
+  var steps = [];
   var default_axis_px = 16;
 
    function wait_until_then(timeout, condFun, readyFun) {
@@ -185,6 +185,31 @@ var animint = function (to_select, json_file) {
 
   var add_geom = function (g_name, g_info) {
     // Determine if data will be an object or an array.
+    // added geom properties in steps array
+    var geom = g_info.classed;
+    var title = g_info.params.title || g_info.classed;
+    var helpText = g_info.params.help || '';
+    var help_showSelected = g_info.params.help_showSelected || '';
+    var help_clickSelects = g_info.params.help_clickSelects || '';
+    var description = helpText;
+    if(g_info.params.hasOwnProperty("showSelected")){
+      if(description != "")description += '<br>';
+      description += 'Data are shown for the current selection of: ' + help_showSelected;
+    }
+    if(g_info.params.hasOwnProperty("clickSelects")){
+      if(description != "")description += '<br>';
+      description += 'Click to select: ' + help_clickSelects;
+    }
+    if(description == ""){
+      description = "No interactions available";
+    }
+    steps.push({  // this add the geom to the steps array for guided tour
+      element: '#' + viz_id + ' .' + geom,
+      popover: {
+        title: title,
+        description: description
+      }
+    });
     if(g_info.geom in data_object_geoms){
       g_info.data_is_object = true;
     }else{
@@ -2053,12 +2078,26 @@ var animint = function (to_select, json_file) {
     ////////////////////////////////////////////
     // Widgets at bottom of page
     ////////////////////////////////////////////
+     // Function to start the tour
+     var element = d3.select('body');
     if(response.hasOwnProperty("source")){
       widget_td.append("a")
 	.attr("class","a_source_href")
 	.attr("href", response.source)
 	.text("source");
     }
+    widget_td
+      .append('button')
+      .attr('class', 'animint_start_tour')
+      .text('Start Tour')
+      .on('click', function () {
+        const driver = window.driver.js.driver;
+        const driverObj = driver({
+          showProgress: true,
+          steps: steps,
+        });
+        driverObj.drive();
+      });
     // loading table.
     var show_hide_table = widget_td.append("button")
       .text("Show download status table");
@@ -2493,4 +2532,3 @@ var animint = function (to_select, json_file) {
   });
 };
 
-
